@@ -8,7 +8,7 @@ use namespace::autoclean;
 # debugging
 #use Smart::Comments '###', '####';
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 =head1 NAME
 
@@ -65,7 +65,7 @@ of time (e.g. caching).  Builders are your friends :)
     use Moose::Role;
     use namespace::autoclean;
 
-    our $VERSION = '0.002';
+    our $VERSION = '0.003';
 
     has ttl => (is => 'ro', isa => 'Int', required => 1, predicate => 'has_ttl');
 
@@ -193,7 +193,7 @@ of time (e.g. caching).  Builders are your friends :)
     use Moose::Role;
     use namespace::autoclean;
 
-    our $VERSION = '0.002';
+    our $VERSION = '0.003';
 
     # debug!
     #before _eval_closure => sub { print "$_[2]\n" };
@@ -251,7 +251,7 @@ of time (e.g. caching).  Builders are your friends :)
         my $mi        = $attr->associated_class->instance_metaclass;
 
         my $deinit;
-        $deinit .= $mi->inline_deinitialize_slot('$_[0]', $_)
+        $deinit .= $mi->inline_deinitialize_slot('$_[0]', $_) . ';'
             for $attr->slots;
 
         my ( $code, $e ) = $self->_eval_closure(
